summaryrefslogtreecommitdiffstats
path: root/lib/network
diff options
context:
space:
mode:
authorOlivier Blin <oblin@mandriva.com>2008-05-15 16:53:03 +0000
committerOlivier Blin <oblin@mandriva.com>2008-05-15 16:53:03 +0000
commit4b1e824fb596fcf6154104b6601ae36e3d06733a (patch)
tree4a551faebd8fb5dce45f8751e6b070ab098fae83 /lib/network
parent6e59d0ca9e38eaeb14e238aec720478ea0001185 (diff)
downloaddrakx-net-4b1e824fb596fcf6154104b6601ae36e3d06733a.tar
drakx-net-4b1e824fb596fcf6154104b6601ae36e3d06733a.tar.gz
drakx-net-4b1e824fb596fcf6154104b6601ae36e3d06733a.tar.bz2
drakx-net-4b1e824fb596fcf6154104b6601ae36e3d06733a.tar.xz
drakx-net-4b1e824fb596fcf6154104b6601ae36e3d06733a.zip
call comgt instead of gcom
Diffstat (limited to 'lib/network')
-rw-r--r--lib/network/connection/cellular_card.pm10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/network/connection/cellular_card.pm b/lib/network/connection/cellular_card.pm
index 06032be..084ff35 100644
--- a/lib/network/connection/cellular_card.pm
+++ b/lib/network/connection/cellular_card.pm
@@ -64,7 +64,7 @@ sub check_hardware_is_slow() { 1 }
sub get_networks {
my ($self) = @_;
- my $cmd = "gcom -d " . $self->get_tty_device;
+ my $cmd = "comgt -d " . $self->get_tty_device;
my ($network, $state) = `$cmd reg` =~ /^Registered on \w+ network: "(.*)",(\d+)$/m;
my ($strength) = `$cmd sig` =~ /^Signal Quality:\s+(\d+),\d+$/;
$self->{networks} = $network && {
@@ -100,8 +100,8 @@ sub get_peer_default_options {
sub build_peer {
my ($self) = @_;
$self->SUPER::build_peer;
#- don't run gcom for now, it hangs on ttyUSB0 devices when run from pppd
#- $self->{access}{peer}->{init} = "gcom -d $dev < $pin_file"
}
sub write_settings {
@@ -167,7 +167,7 @@ sub check_hardware {
require c;
use POSIX qw(:errno_h);
- my $pid = IPC::Open2::open2(my $cmd_out, my $cmd_in, "gcom", "-d", $self->get_tty_device);
+ my $pid = IPC::Open2::open2(my $cmd_out, my $cmd_in, "comgt", "-d", $self->get_tty_device);
common::nonblock($cmd_out);
my $selector = IO::Select->new($cmd_out);
my $already_entered_pin;
@@ -192,7 +192,7 @@ sub check_hardware {
Entering the wrong PIN code multiple times may lock your SIM card!");
last;
} elsif (/^Waiting for Registration/m) {
#- the card seems to be resetted if gcom is killed right here, wait a bit
sleep 1;
#- don't wait the full scan
$device_ready = 1;
@@ -100,8 +100,8 @@ sub get_peer_default_options {
my ($self) = @_;
$self->SUPER::build_peer;
- #- don't run gcom for now, it hangs on ttyUSB0 devices when run from pppd
- #- $self->{access}{peer}->{init} = "gcom -d $dev < $pin_file"
+ #- don't run comgt for now, it hangs on ttyUSB0 devices when run from pppd
+ #- $self->{access}{peer}->{init} = "comgt -d $dev < $pin_file"
}
sub write_settings {
@@ -192,7 +192,7 @@ sub check_hardware {
last;
} elsif (/^Waiting for Registration/m) {
- #- the card seems to be resetted if gcom is killed right here, wait a bit
+ #- the card seems to be resetted if comgt is killed right here, wait a bit
sleep 1;
#- don't wait the full scan